@@ -1056,6 +1056,54 @@ cut_assert_not_equal_double_helper (double          expected,
     }
 }
 
+static const gchar *
+taken_inspect_char (char value)
+{
+    const gchar *inspected;
+    GString *inspected_buffer;
+
+    inspected_buffer = g_string_new(NULL);
+    gcut_inspect_char(inspected_buffer, &value, NULL);
+    inspected = cut_take_strdup(inspected_buffer->str);
+    g_string_free(inspected_buffer, TRUE);
+
+    return inspected;
+}
+
+void
+cut_assert_equal_char_helper (char            expected,
+                              char            actual,
+                              const char     *expression_expected,
+                              const char     *expression_actual)
+{
+    if (expected == actual) {
+        cut_test_pass();
+    } else {
+        cut_set_expected(taken_inspect_char(expected));
+        cut_set_actual(taken_inspect_char(actual));
+        cut_test_fail(cut_take_printf("<%s == %s>",
+                                      expression_expected,
+                                      expression_actual));
+    }
+}
+
+void
+cut_assert_not_equal_char_helper (const char      expected,
+                                  const char      actual,
+                                  const char     *expression_expected,
+                                  const char     *expression_actual)
+{
+    if (expected != actual) {
+        cut_test_pass();
+    } else {
+        cut_set_expected(taken_inspect_char(expected));
+        cut_set_actual(taken_inspect_char(actual));
+        cut_test_fail(cut_take_printf("<%s != %s>",
+                                      expression_expected,
+                                      expression_actual));
+    }
+}
+
 void
 cut_assert_equal_string_helper (const char     *expected,
                                 const char     *actual,
@@ -1066,23 +1114,20 @@ cut_assert_equal_string_helper (const char     *expected,
         if (actual == NULL) {
             cut_test_pass();
         } else {
-            cut_test_fail(cut_take_printf("expected: <%s> is NULL\n"
-                                          "  actual: <%s>",
-                                          expression_actual,
-                                          actual));
+            cut_set_expected(cut_take_inspect_string(expected));
+            cut_set_actual(cut_take_inspect_string(actual));
+            cut_test_fail(cut_take_printf("<%s == NULL>",
+                                          expression_actual));
         }
     } else {
         if (cut_utils_equal_string(expected, actual)) {
             cut_test_pass();
         } else {
-            const char *message;
-
-            message = cut_take_printf("<%s == %s>",
-                                      expression_expected,
-                                      expression_actual);
-            cut_set_expected(expected);
-            cut_set_actual(actual);
-            cut_test_fail(message);
+            cut_set_expected(cut_take_inspect_string(expected));
+            cut_set_actual(cut_take_inspect_string(actual));
+            cut_test_fail(cut_take_printf("<%s == %s>",
+                                          expression_expected,
+                                          expression_actual));
         }
     }
 }
@@ -1097,23 +1142,20 @@ cut_assert_not_equal_string_helper (const char     *expected,
         if (actual) {
             cut_test_pass();
         } else {
-            cut_test_fail(cut_take_printf("expected: <%s> is not NULL\n"
-                                          "  actual: <%s>",
-                                          expression_actual,
-                                          actual));
+            cut_set_expected(cut_take_inspect_string(expected));
+            cut_set_actual(cut_take_inspect_string(actual));
+            cut_test_fail(cut_take_printf("<%s != NULL>",
+                                          expression_actual));
         }
     } else {
         if (!cut_utils_equal_string(expected, actual)) {
             cut_test_pass();
         } else {
-            const char *message;
-
-            message = cut_take_printf("<%s != %s>",
-                                      expression_expected,
-                                      expression_actual);
-            cut_set_expected(expected);
-            cut_set_actual(actual);
-            cut_test_fail(message);
+            cut_set_expected(cut_take_inspect_string(expected));
+            cut_set_actual(cut_take_inspect_string(actual));
+            cut_test_fail(cut_take_printf("<%s != %s>",
+                                          expression_expected,
+                                          expression_actual));
         }
     }
 }
@@ -1133,27 +1175,24 @@ cut_assert_equal_substring_helper (const char     *expected,
             const gchar *actual_substring;
 
             actual_substring = cut_take_string(g_strndup(actual, length));
-            cut_test_fail(cut_take_printf("expected: <%s> is NULL\n"
-                                          "  actual: <%s>",
-                                          expression_actual,
-                                          actual_substring));
+            cut_set_expected(cut_take_inspect_string(expected));
+            cut_set_actual(cut_take_inspect_string(actual_substring));
+            cut_test_fail(cut_take_printf("<%s == NULL>",
+                                          expression_actual));
         }
     } else {
         if (cut_utils_equal_substring(expected, actual, length)) {
             cut_test_pass();
         } else {
-            const gchar *actual_substring;
-            const char *message;
+            const gchar *actual_substring = NULL;
 
             actual_substring = cut_take_string(g_strndup(actual, length));
-            message =
-                cut_take_printf("<%s == (%s)[0..%s]>",
-                                expression_expected,
-                                expression_actual,
-                                expression_length);
-            cut_set_expected(expected);
-            cut_set_actual(actual_substring);
-            cut_test_fail(message);
+            cut_set_expected(cut_take_inspect_string(expected));
+            cut_set_actual(cut_take_inspect_string(actual_substring));
+            cut_test_fail(cut_take_printf("<%s == (%s)[0..%s]>",
+                                          expression_expected,
+                                          expression_actual,
+                                          expression_length));
         }
     }
 }
@@ -1173,28 +1212,24 @@ cut_assert_not_equal_substring_helper (const char     *expected,
             const gchar *actual_substring;
 
             actual_substring = cut_take_string(g_strndup(actual, length));
-            cut_test_fail(cut_take_printf("expected: <%s> is not NULL\n"
-                                          "  actual: <%s>",
-                                          expression_actual,
-                                          actual_substring));
+            cut_set_expected(cut_take_inspect_string(expected));
+            cut_set_actual(cut_take_inspect_string(actual_substring));
+            cut_test_fail(cut_take_printf("<%s != NULL>",
+                                          expression_actual));
         }
     } else {
         if (!cut_utils_equal_substring(expected, actual, length)) {
             cut_test_pass();
         } else {
-            const gchar *actual_substring = NULL;
-            const char *message;
+            const gchar *actual_substring;
 
-            if (actual)
-                actual_substring = cut_take_string(g_strndup(actual, length));
-            message =
-                cut_take_printf("<%s != (%s)[0..%s]>",
-                                expression_expected,
-                                expression_actual,
-                                expression_length);
-            cut_set_expected(expected);
-            cut_set_actual(actual_substring);
-            cut_test_fail(message);
+            actual_substring = cut_take_string(g_strndup(actual, length));
+            cut_set_expected(cut_take_inspect_string(expected));
+            cut_set_actual(cut_take_inspect_string(actual_substring));
+            cut_test_fail(cut_take_printf("<%s != (%s)[0..%s]>",
+                                          expression_expected,
+                                          expression_actual,
+                                          expression_length));
         }
     }
 }
@@ -1437,7 +1472,7 @@ cut_assert_errno_helper (void)
 }
 
 void
-cut_assert_path_exist_helper (const char     *path,
+cut_assert_exist_path_helper (const char     *path,
                               const char     *expression_path)
 {
     if (!path) {
@@ -1457,7 +1492,7 @@ cut_assert_path_exist_helper (const char     *path,
 }
 
 void
-cut_assert_path_not_exist_helper (const char     *path,
+cut_assert_not_exist_path_helper (const char     *path,
                                   const char     *expression_path)
 {
     if (!path) {
@@ -1514,24 +1549,124 @@ cut_assert_equal_pointer_helper (const void     *expected,
 }
 
 void
-cut_assert_equal_fixture_data_string_helper (const void     *expected,
-                                             const gchar    *expression_expected,
-                                             const void     *path,
+cut_assert_equal_fixture_data_string_helper (const char     *expected,
+                                             const char     *expression_expected,
+                                             const char     *path,
                                              ...)
 {
     GError *error = NULL;
-    const char *data;
-    char *full_path;
+    const gchar *data;
+    const gchar *full_path;
     va_list args;
 
     va_start(args, path);
-    data = cut_utils_get_fixture_data_string_va_list(
-        cut_get_current_test_context(), &full_path, path, args);
+    data = cut_utils_get_fixture_data_va_list(
+        cut_get_current_test_context(), &full_path, NULL, path, args);
     cut_test_context_keep_user_message(cut_get_current_test_context());
     gcut_assert_error_helper(error, expression_expected);
     cut_assert_equal_string_helper(expected, data,
                                    expression_expected,
-                                   cut_take_string(full_path));
+                                   full_path);
+}
+
+void
+cut_assert_equal_file_raw_helper (const char     *expected,
+                                  const char     *actual,
+                                  const char     *expression_expected,
+                                  const char     *expression_actual)
+{
+    GError *error = NULL;
+    gchar *expected_data = NULL;
+    gchar *actual_data = NULL;
+    gsize expected_size;
+    gsize actual_size;
+
+    g_file_get_contents(expected, &expected_data, &expected_size, &error);
+    gcut_assert_error_helper(error, expression_expected);
+    cut_take_string(expected_data);
+
+    g_file_get_contents(actual, &actual_data, &actual_size, &error);
+    gcut_assert_error_helper(error, expression_actual);
+    cut_take_string(actual_data);
+
+    if ((expected_size == actual_size) &&
+        memcmp(expected_data, actual_data, expected_size) == 0) {
+        cut_test_pass();
+    } else {
+        const char *message;
+        const char *inspected_expected;
+        const char *inspected_actual;
+
+        inspected_expected =
+            cut_take_string(cut_utils_inspect_memory(expected_data,
+                                                     expected_size));
+        inspected_actual =
+            cut_take_string(cut_utils_inspect_memory(actual_data, actual_size));
+        message = cut_take_printf("<content(%s) == content(%s)>",
+                                  expression_expected,
+                                  expression_actual);
+        cut_set_expected(cut_take_printf("path: <%s>\n"
+                                         "%s (size: %" G_GSIZE_FORMAT ")",
+                                         expected,
+                                         inspected_expected,
+                                         expected_size));
+        cut_set_actual(cut_take_printf("path: <%s>\n"
+                                       "%s (size: %" G_GSIZE_FORMAT ")",
+                                       actual,
+                                       inspected_actual,
+                                       actual_size));
+        cut_test_fail(message);
+    }
+}
+
+void
+cut_assert_not_equal_file_raw_helper (const char     *expected,
+                                      const char     *actual,
+                                      const char     *expression_expected,
+                                      const char     *expression_actual)
+{
+    GError *error = NULL;
+    gchar *expected_data = NULL;
+    gchar *actual_data = NULL;
+    gsize expected_size;
+    gsize actual_size;
+
+    g_file_get_contents(expected, &expected_data, &expected_size, &error);
+    gcut_assert_error_helper(error, expression_expected);
+    cut_take_string(expected_data);
+
+    g_file_get_contents(actual, &actual_data, &actual_size, &error);
+    gcut_assert_error_helper(error, expression_actual);
+    cut_take_string(actual_data);
+
+    if ((expected_size != actual_size) ||
+        memcmp(expected_data, actual_data, expected_size) != 0) {
+        cut_test_pass();
+    } else {
+        const char *message;
+        const char *inspected_expected;
+        const char *inspected_actual;
+
+        inspected_expected =
+            cut_take_string(cut_utils_inspect_memory(expected_data,
+                                                     expected_size));
+        inspected_actual =
+            cut_take_string(cut_utils_inspect_memory(actual_data, actual_size));
+        message = cut_take_printf("<content(%s) != content(%s)>",
+                                  expression_expected,
+                                  expression_actual);
+        cut_set_expected(cut_take_printf("path: <%s>\n"
+                                         "%s (size: %" G_GSIZE_FORMAT ")",
+                                         expected,
+                                         inspected_expected,
+                                         expected_size));
+        cut_set_actual(cut_take_printf("path: <%s>\n"
+                                       "%s (size: %" G_GSIZE_FORMAT ")",
+                                       actual,
+                                       inspected_actual,
+                                       actual_size));
+        cut_test_fail(message);
+    }
 }
 
 #ifndef CUT_DISABLE_SOCKET_SUPPORT
