@@ -1329,6 +1329,58 @@ extern "C" {
         cut_assert_not_equal_double(expected, error, actual));          \
 } while (0)
 
+/**
+ * cut_assert_equal_char:
+ * @expected: an expected char value.
+ * @actual: an actual char value.
+ * @...: optional message. See cut_message() for details.
+ *
+ * Passes if @expected ==  @actual.
+ *
+ * e.g.:
+ * |[
+ * cut_assert_equal_char('a', 'a'); -> Pass
+ * cut_assert_equal_char('a', 'b'); -> Fail
+ * ]|
+ *
+ * Since: 1.1.3
+ */
+#define cut_assert_equal_char(expected, actual, ...) do                 \
+{                                                                       \
+    cut_trace_with_info_expression(                                     \
+        cut_test_with_user_message(                                     \
+            cut_assert_equal_char_helper(expected, actual,              \
+                                         #expected, #actual),           \
+            __VA_ARGS__),                                               \
+        cut_assert_equal_char(expected, actual, __VA_ARGS__));          \
+} while (0)
+
+/**
+ * cut_assert_not_equal_char:
+ * @expected: an expected char value.
+ * @actual: an actual char value.
+ * @...: optional message. See cut_message() for details.
+ *
+ * Passes if @expected != @actual.
+ *
+ * e.g.:
+ * |[
+ * cut_assert_not_equal_char('a', 'b'); -> Pass
+ * cut_assert_not_equal_char('a', 'a'); -> Fail
+ * ]|
+ *
+ * Since: 1.1.3
+ */
+#define cut_assert_not_equal_char(expected, actual, ...) do             \
+{                                                                       \
+    cut_trace_with_info_expression(                                     \
+        cut_test_with_user_message(                                     \
+            cut_assert_not_equal_char_helper(expected, actual,          \
+                                             #expected, #actual),       \
+            __VA_ARGS__),                                               \
+        cut_assert_not_equal_char(expected, actual));                   \
+} while (0)
+
 /**
  * cut_assert_equal_string:
  * @expected: an expected string value.
@@ -1368,11 +1420,11 @@ extern "C" {
  *
  * e.g.:
  * |[
- * cut_assert_equal_string("abc", "ABC"); -> Pass
- * cut_assert_equal_string("abc", NULL);  -> Pass
- * cut_assert_equal_string(NULL, "abc");  -> Pass
- * cut_assert_equal_string("abc", "abc"); -> Fail
- * cut_assert_equal_string(NULL, NULL);   -> Fail
+ * cut_assert_not_equal_string("abc", NULL);  -> Pass
+ * cut_assert_not_equal_string(NULL, "abc");  -> Pass
+ * cut_assert_not_equal_string("abc", "ABC"); -> Pass
+ * cut_assert_not_equal_string("abc", "abc"); -> Fail
+ * cut_assert_not_equal_string(NULL, NULL);   -> Fail
  * ]|
  *
  * Since: 1.0.7
@@ -1808,11 +1860,10 @@ extern "C" {
 {                                                               \
     cut_trace_with_info_expression(                             \
         cut_test_with_user_message(                             \
-            cut_assert_path_exist(path),                        \
+            cut_assert_exist_path(path),                        \
             __VA_ARGS__),                                       \
         cut_assert_file_exist(path, __VA_ARGS__));              \
 } while (0)
-#endif
 
 /**
  * cut_assert_path_exist:
@@ -1828,16 +1879,43 @@ extern "C" {
  * ]|
  *
  * Since: 1.0.2
+ * Deprecated: 1.1.5: Use cut_assert_exist_path() instead.
  */
 #define cut_assert_path_exist(path, ...) do                     \
 {                                                               \
     cut_trace_with_info_expression(                             \
         cut_test_with_user_message(                             \
-            cut_assert_path_exist_helper(path, #path),          \
+            cut_assert_exist_path_helper(path, #path),          \
             __VA_ARGS__),                                       \
         cut_assert_path_exist(path, __VA_ARGS__));              \
 } while (0)
+#endif
 
+/**
+ * cut_assert_exist_path:
+ * @path: the path to test.
+ * @...: optional message. See cut_message() for details.
+ *
+ * Passes if @path exists. It may or may not be a regular file.
+ *
+ * e.g.:
+ * |[
+ * cut_assert_exist_path("/tmp");             -> Pass on many environment
+ * cut_assert_exist_path("/non-existent");    -> Fail
+ * ]|
+ *
+ * Since: 1.1.5
+ */
+#define cut_assert_exist_path(path, ...) do                     \
+{                                                               \
+    cut_trace_with_info_expression(                             \
+        cut_test_with_user_message(                             \
+            cut_assert_exist_path_helper(path, #path),          \
+            __VA_ARGS__),                                       \
+        cut_assert_exist_path(path, __VA_ARGS__));              \
+} while (0)
+
+#ifndef CUTTER_DISABLE_DEPRECATED
 /**
  * cut_assert_path_not_exist:
  * @path: the path to test.
@@ -1852,15 +1930,41 @@ extern "C" {
  * ]|
  *
  * Since: 1.0.2
+ * Deprecated: 1.1.5: Use cut_assert_not_exist_path() instead.
  */
 #define cut_assert_path_not_exist(path, ...) do                 \
 {                                                               \
     cut_trace_with_info_expression(                             \
         cut_test_with_user_message(                             \
-            cut_assert_path_not_exist_helper(path, #path),      \
+            cut_assert_not_exist_path_helper(path, #path),      \
             __VA_ARGS__),                                       \
         cut_assert_path_not_exist(path, __VA_ARGS__));          \
 } while (0)
+#endif
+
+/**
+ * cut_assert_not_exist_path:
+ * @path: the path to test.
+ * @...: optional message. See cut_message() for details.
+ *
+ * Passes if @path doesn't exist.
+ *
+ * e.g.:
+ * |[
+ * cut_assert_not_exist_path("/non-existent");    -> Pass on many environment
+ * cut_assert_not_exist_path("/tmp");             -> Fail
+ * ]|
+ *
+ * Since: 1.1.5
+ */
+#define cut_assert_not_exist_path(path, ...) do                 \
+{                                                               \
+    cut_trace_with_info_expression(                             \
+        cut_test_with_user_message(                             \
+            cut_assert_not_exist_path_helper(path, #path),      \
+            __VA_ARGS__),                                       \
+        cut_assert_not_exist_path(path, __VA_ARGS__));          \
+} while (0)
 
 /**
  * cut_assert_match:
@@ -1974,6 +2078,46 @@ extern "C" {
 } while (0)
 #endif
 
+/**
+ * cut_assert_equal_file_raw:
+ * @expected: a path.
+ * @actual: a path.
+ * @...: optional message. See cut_message() for details.
+ *
+ * Passes if the content of @expected == the content of @actual.
+ *
+ * Since: 1.1.4
+ */
+#define cut_assert_equal_file_raw(expected, actual, ...) do             \
+{                                                                       \
+    cut_trace_with_info_expression(                                     \
+        cut_test_with_user_message(                                     \
+            cut_assert_equal_file_raw_helper(expected, actual,          \
+                                             #expected, #actual),       \
+            __VA_ARGS__),                                               \
+        cut_assert_equal_file_raw(expected, actual, __VA_ARGS__));      \
+} while (0)
+
+/**
+ * cut_assert_not_equal_file_raw:
+ * @expected: a path.
+ * @actual: a path.
+ * @...: optional message. See cut_message() for details.
+ *
+ * Passes if the content of @expected != the content of @actual.
+ *
+ * Since: 1.1.4
+ */
+#define cut_assert_not_equal_file_raw(expected, actual, ...) do         \
+{                                                                       \
+    cut_trace_with_info_expression(                                     \
+        cut_test_with_user_message(                                     \
+            cut_assert_not_equal_file_raw_helper(expected, actual,      \
+                                                 #expected, #actual),   \
+            __VA_ARGS__),                                               \
+        cut_assert_not_equal_file_raw(expected, actual, __VA_ARGS__));  \
+} while (0)
+
 /**
  * cut_error:
  * @format: the message format. See the printf() documentation.
