@@ -93,7 +93,7 @@ struct _CutTestContextPrivate
     gchar *expected;
     gchar *actual;
     CutTestResult *current_result;
-    gboolean have_user_message_jump;
+    guint user_message_jump_nest;
 };
 
 enum
@@ -231,6 +231,13 @@ cut_test_context_class_init (CutTestContextClass *klass)
     g_type_class_add_private(gobject_class, sizeof(CutTestContextPrivate));
 }
 
+static void
+fixture_data_free (gpointer data)
+{
+    GString *string = data;
+    g_string_free(string, TRUE);
+}
+
 static void
 cut_test_context_init (CutTestContext *context)
 {
@@ -255,7 +262,7 @@ cut_test_context_init (CutTestContext *context)
 
     priv->fixture_data_dir = NULL;
     priv->cached_fixture_data = g_hash_table_new_full(g_str_hash, g_str_equal,
-                                                      g_free, g_free);
+                                                      g_free, fixture_data_free);
 
     priv->backtrace = NULL;
 
@@ -269,7 +276,7 @@ cut_test_context_init (CutTestContext *context)
 
     priv->current_result = NULL;
 
-    priv->have_user_message_jump = FALSE;
+    priv->user_message_jump_nest = 0;
 }
 
 static void
@@ -947,16 +954,21 @@ cut_test_context_register_result (CutTestContext *context,
 }
 
 void
-cut_test_context_set_have_user_message_jump (CutTestContext *context,
-                                             gboolean have)
+cut_test_context_start_user_message_jump (CutTestContext *context)
 {
-    CUT_TEST_CONTEXT_GET_PRIVATE(context)->have_user_message_jump = have;
+    CUT_TEST_CONTEXT_GET_PRIVATE(context)->user_message_jump_nest++;
+}
+
+void
+cut_test_context_finish_user_message_jump (CutTestContext *context)
+{
+    CUT_TEST_CONTEXT_GET_PRIVATE(context)->user_message_jump_nest--;
 }
 
 gboolean
-cut_test_context_get_have_user_message_jump (CutTestContext *context)
+cut_test_context_in_user_message_jump (CutTestContext *context)
 {
-    return CUT_TEST_CONTEXT_GET_PRIVATE(context)->have_user_message_jump;
+    return CUT_TEST_CONTEXT_GET_PRIVATE(context)->user_message_jump_nest > 0;
 }
 
 void
@@ -1092,6 +1104,21 @@ cut_test_context_take_g_hash_table (CutTestContext *context,
                                                (CutDestroyFunction)g_hash_table_unref);
 }
 
+static void
+cut_test_context_g_string_free (GString *string)
+{
+    g_string_free(string, TRUE);
+}
+
+GString *
+cut_test_context_take_g_string (CutTestContext *context,
+                                GString        *string)
+{
+    return (GString *)cut_test_context_take(context,
+                                            string,
+                                            (CutDestroyFunction) cut_test_context_g_string_free);
+}
+
 int
 cut_test_context_trap_fork (CutTestContext *context)
 {
@@ -1263,106 +1290,106 @@ cut_test_context_set_fixture_data_dir (CutTestContext *context,
     va_end(args);
 }
 
-gchar *
-cut_test_context_build_fixture_data_path_va_list (CutTestContext *context,
-                                                  const gchar *path,
-                                                  va_list args)
+const gchar *
+cut_test_context_build_fixture_path_va_list (CutTestContext *context,
+                                             const gchar *path,
+                                             va_list args)
 {
     CutTestContextPrivate *priv;
-    gchar *concatenated_path, *full_path;
+    gchar *concatenated_path;
+    const gchar *full_path;
 
     priv = CUT_TEST_CONTEXT_GET_PRIVATE(context);
 
     concatenated_path = cut_utils_build_path_va_list(path, args);
     if (g_path_is_absolute(concatenated_path)) {
-        full_path = concatenated_path;
+        full_path = cut_test_context_take_string(context, concatenated_path);
     } else {
+        gchar *resolved_path;
         if (priv->fixture_data_dir) {
-            full_path = g_build_filename(priv->fixture_data_dir,
-                                         concatenated_path,
-                                         NULL);
+            resolved_path = g_build_filename(priv->fixture_data_dir,
+                                             concatenated_path,
+                                             NULL);
         } else {
-            full_path = cut_utils_expand_path(concatenated_path);
+            resolved_path = cut_utils_expand_path(concatenated_path);
         }
-        g_free(concatenated_path);
+        full_path = cut_test_context_take_string(context, resolved_path);
     }
-
-    return full_path;
-}
-
-gchar *
-cut_test_context_build_fixture_data_path (CutTestContext *context,
-                                          const gchar *path, ...)
-{
-    va_list args;
-    gchar *full_path;
-
-    va_start(args, path);
-    full_path = cut_test_context_build_fixture_data_path_va_list(context,
-                                                                 path, args);
-    va_end(args);
+    g_free(concatenated_path);
 
     return full_path;
 }
 
 const gchar *
-cut_test_context_get_fixture_data_string_va_list (CutTestContext *context,
-                                                  GError **error,
-                                                  gchar **full_path,
-                                                  const gchar *path,
-                                                  va_list args)
+cut_test_context_build_fixture_path (CutTestContext *context,
+                                     const gchar *path, ...)
+{
+    va_list args;
+    const gchar *full_path;
+
+    va_start(args, path);
+    full_path = cut_test_context_build_fixture_path_va_list(context, path, args);
+    va_end(args);
+
+    return full_path;
+}
+
+GString *
+cut_test_context_get_fixture_data_va_list (CutTestContext *context,
+                                           GError **error,
+                                           const gchar **full_path,
+                                           const gchar *path,
+                                           va_list args)
 {
     CutTestContextPrivate *priv;
-    gpointer value;
-    gchar *_full_path;
+    GString *data;
+    const gchar *fixture_full_path;
 
     if (!path)
         return NULL;
 
     priv = CUT_TEST_CONTEXT_GET_PRIVATE(context);
 
-    _full_path = cut_test_context_build_fixture_data_path_va_list(context,
-                                                                  path, args);
-    value = g_hash_table_lookup(priv->cached_fixture_data, _full_path);
-    if (!value) {
+    fixture_full_path = cut_test_context_build_fixture_path_va_list(context,
+                                                                    path, args);
+    data = g_hash_table_lookup(priv->cached_fixture_data, fixture_full_path);
+    if (!data) {
         gchar *contents;
         gsize length;
 
-        if (g_file_get_contents(_full_path, &contents, &length, error)) {
+        if (g_file_get_contents(fixture_full_path, &contents, &length, error)) {
+            data = g_string_new_len(contents, length);
+            g_free(contents);
             g_hash_table_insert(priv->cached_fixture_data,
-                                g_strdup(_full_path),
-                                contents);
-            value = contents;
+                                g_strdup(fixture_full_path),
+                                data);
         }
     }
 
     if (full_path)
-        *full_path = _full_path;
-    else
-        g_free(_full_path);
+        *full_path = fixture_full_path;
 
-    return value;
+    return data;
 }
 
-const gchar *
-cut_test_context_get_fixture_data_string (CutTestContext *context,
-                                          GError **error,
-                                          gchar **full_path,
-                                          const gchar *path, ...)
+GString *
+cut_test_context_get_fixture_data (CutTestContext *context,
+                                   GError **error,
+                                   const gchar **full_path,
+                                   const gchar *path, ...)
 {
-    const gchar *value;
+    GString *data;
     va_list args;
 
     if (!path)
         return NULL;
 
     va_start(args, path);
-    value = cut_test_context_get_fixture_data_string_va_list(context, error,
-                                                             full_path,
-                                                             path, args);
+    data = cut_test_context_get_fixture_data_va_list(context, error,
+                                                     full_path, path, args);
     va_end(args);
 
-    return value;
+    return data;
 }
 
 gchar *
