@@ -220,6 +220,31 @@ cut_utils_equal_string_array (gchar **strings1, gchar **strings2)
     return TRUE;
 }
 
+static void
+cut_utils_inspect_string_to_gstring (GString *inspected, const gchar *string)
+{
+    if (!string) {
+        g_string_append(inspected, "(null)");
+        return;
+    }
+
+    g_string_append_c(inspected, '"');
+    for (; string[0]; string++) {
+        switch (string[0]) {
+        case '"':
+            g_string_append(inspected, "\\\"");
+            break;
+        case '\\':
+            g_string_append(inspected, "\\\\");
+            break;
+        default:
+            g_string_append_c(inspected, string[0]);
+            break;
+        }
+    }
+    g_string_append_c(inspected, '"');
+}
+
 gchar *
 cut_utils_inspect_string_array (gchar **strings)
 {
@@ -232,7 +257,7 @@ cut_utils_inspect_string_array (gchar **strings)
     inspected = g_string_new("[");
     string = strings;
     while (*string) {
-        g_string_append_printf(inspected, "\"%s\"", *string);
+        cut_utils_inspect_string_to_gstring(inspected, *string);
         next_string = string + 1;
         if (*next_string)
             g_string_append(inspected, ", ");
@@ -243,13 +268,14 @@ cut_utils_inspect_string_array (gchar **strings)
     return g_string_free(inspected, FALSE);
 }
 
-const gchar *
+gchar *
 cut_utils_inspect_string (const gchar *string)
 {
-    if (string)
-        return string;
-    else
-        return "(null)";
+    GString *inspected;
+
+    inspected = g_string_new(NULL);
+    cut_utils_inspect_string_to_gstring(inspected, string);
+    return g_string_free(inspected, FALSE);
 }
 
 #ifndef CUT_DISABLE_SOCKET_SUPPORT
@@ -431,50 +457,42 @@ cut_utils_regex_replace (const gchar *pattern, const gchar *string,
 }
 
 const gchar *
-cut_utils_get_fixture_data_string (CutTestContext *context,
-                                   gchar **fixture_data_path,
-                                   const char *path,
-                                   ...)
+cut_utils_get_fixture_data (CutTestContext *context,
+                            const gchar **fixture_data_path,
+                            gsize *size,
+                            const char *path,
+                            ...)
 {
     const gchar *data;
     va_list args;
 
     va_start(args, path);
-    data = cut_utils_get_fixture_data_string_va_list(context, fixture_data_path,
-                                                     path, args);
+    data = cut_utils_get_fixture_data_va_list(context, fixture_data_path, size,
+                                              path, args);
     va_end(args);
 
     return data;
 }
 
 const gchar *
-cut_utils_get_fixture_data_string_va_list (CutTestContext *context,
-                                           gchar **fixture_data_path,
-                                           const gchar *path,
-                                           va_list args)
+cut_utils_get_fixture_data_va_list (CutTestContext *context,
+                                    const gchar **fixture_data_path,
+                                    gsize *size,
+                                    const gchar *path,
+                                    va_list args)
 {
-    GError *error = NULL;
-    const gchar *fixture_data;
+    GString *fixture_data;
 
-    fixture_data =
-        cut_test_context_get_fixture_data_string_va_list(context, &error,
-                                                         fixture_data_path,
-                                                         path, args);
-    if (error) {
-        gchar *inspected, *message;
+    fixture_data = gcut_utils_get_fixture_data_va_list(context,
+                                                       fixture_data_path,
+                                                       path, args);
+    if (!fixture_data)
+        return NULL;
 
-        inspected = gcut_error_inspect(error);
-        message = g_strdup_printf("can't get fixture data: %s", inspected);
-        g_error_free(error);
-        cut_test_context_register_result(context,
-                                         CUT_TEST_RESULT_ERROR,
-                                         message);
-        g_free(inspected);
-        g_free(message);
-        cut_test_context_long_jump(context);
-    }
+    if (size)
+        *size = fixture_data->len;
 
-    return fixture_data;
+    return fixture_data->str;
 }
 
 void
@@ -605,12 +623,19 @@ cut_utils_build_path_va_list (const gchar *path, va_list args)
     while ((element = va_arg(args, gchar *))) {
         g_array_append_val(elements, element);
     }
-    concatenated_path = g_build_filenamev((gchar **)(elements->data));
+    concatenated_path =
+        cut_utils_build_path_array((const gchar **)(elements->data));
     g_array_free(elements, TRUE);
 
     return concatenated_path;
 }
 
+gchar *
+cut_utils_build_path_array (const gchar **paths)
+{
+    return g_build_filenamev((gchar **)paths);
+}
+
 gchar *
 cut_utils_expand_path (const gchar *path)
 {
