@@ -1,6 +1,6 @@
 /* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
- *  Copyright (C) 2008-2009  Kouhei Sutou <kou@clear-code.com>
+ *  Copyright (C) 2008-2010  Kouhei Sutou <kou@clear-code.com>
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -329,7 +329,7 @@ gcut_assert_error_helper (GError         *error,
         const gchar *inspected;
 
         inspected = cut_take_string(gcut_error_inspect(error));
-        g_clear_error(&error);
+        g_error_free(error);
         cut_test_fail(cut_take_printf("expected: <%s> is NULL\n"
                                       "  actual: <%s>",
                                       expression_error, inspected));
@@ -490,6 +490,23 @@ gcut_assert_equal_int64_helper (gint64          expected,
     }
 }
 
+void
+gcut_assert_not_equal_int64_helper (gint64         expected,
+                                    gint64         actual,
+                                    const char     *expression_expected,
+                                    const char     *expression_actual)
+{
+    if (expected != actual) {
+        cut_test_pass();
+    } else {
+        cut_set_expected(cut_take_printf("%" G_GINT64_FORMAT, expected));
+        cut_set_actual(cut_take_printf("%" G_GINT64_FORMAT, actual));
+        cut_test_fail(cut_take_printf("<%s != %s>",
+                                      expression_expected,
+                                      expression_actual));
+    }
+}
+
 void
 gcut_assert_equal_uint64_helper (guint64         expected,
                                  guint64         actual,
@@ -507,6 +524,23 @@ gcut_assert_equal_uint64_helper (guint64         expected,
     }
 }
 
+void
+gcut_assert_not_equal_uint64_helper (guint64         expected,
+                                     guint64         actual,
+                                     const char     *expression_expected,
+                                     const char     *expression_actual)
+{
+    if (expected != actual) {
+        cut_test_pass();
+    } else {
+        cut_set_expected(cut_take_printf("%" G_GUINT64_FORMAT, expected));
+        cut_set_actual(cut_take_printf("%" G_GUINT64_FORMAT, actual));
+        cut_test_fail(cut_take_printf("<%s != %s>",
+                                      expression_expected,
+                                      expression_actual));
+    }
+}
+
 #ifdef G_OS_WIN32
 #define GCUT_GPID_FORMAT "p"
 #else
@@ -546,6 +580,29 @@ gcut_assert_not_equal_pid_helper (GPid            expected,
     }
 }
 
+void
+gcut_assert_equal_string_helper (const GString  *expected,
+                                 const GString  *actual,
+                                 const gchar    *expression_expected,
+                                 const gchar    *expression_actual)
+{
+    if (gcut_string_equal(expected, actual)) {
+        cut_test_pass();
+    } else {
+        const gchar *message;
+        const gchar *inspected_expected, *inspected_actual;
+
+        inspected_expected = cut_take_string(gcut_string_inspect(expected));
+        inspected_actual = cut_take_string(gcut_string_inspect(actual));
+
+        message = cut_take_printf("<%s == %s>",
+                                  expression_expected, expression_actual);
+        cut_set_expected(inspected_expected);
+        cut_set_actual(inspected_actual);
+        cut_test_fail(message);
+    }
+}
+
 /*
 vi:ts=4:nowrap:ai:expandtab:sw=4
 */
