@@ -1,4 +1,21 @@
 /* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
+/*
+ *  Copyright (C) 2008-2010  Kouhei Sutou <kou@clear-code.com>
+ *
+ *  This library is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU Lesser General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This library is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU Lesser General Public License for more details.
+ *
+ *  You should have received a copy of the GNU Lesser General Public License
+ *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ */
 
 #include <gcutter.h>
 #include <cutter/cut-sequence-matcher.h>
@@ -21,6 +38,7 @@ void test_get_operations_for_char_sequence(void);
 void test_get_grouped_operations(void);
 void test_get_ratio_for_string_sequence(void);
 void test_get_ratio_for_char_sequence(void);
+void test_set_context_size(void);
 
 static CutSequenceMatcher *matcher;
 static GList *expected_indexes;
@@ -398,11 +416,11 @@ test_get_longest_match_for_string_sequence (void)
     gchar *qabxcd[] = {"q", "a", "b", "x", "c", "d", NULL};
     gchar *abycdf[] = {"a", "b", "y", "c", "d", "f", NULL};
 
-    cut_assert_longest_match_string(0, 1, 3, bcd, abcdxyz, 0, 2, 0, 7);
-    cut_assert_longest_match_string(1, 2, 2, bcd, abcdxyz, 1, 2, 0, 6);
-    cut_assert_longest_match_string(0, 0, 0, ab, c, 0, 1, 0, 0);
-    cut_assert_longest_match_string(1, 0, 2, qabxcd, abycdf, 0, 5, 0, 5);
-    cut_assert_longest_match_string(4, 3, 2, qabxcd, abycdf, 3, 5, 2, 5);
+    cut_assert_longest_match_string(0, 1, 3, bcd, abcdxyz, 0, 3, 0, 8);
+    cut_assert_longest_match_string(1, 2, 2, bcd, abcdxyz, 1, 3, 0, 7);
+    cut_assert_longest_match_string(0, 0, 0, ab, c, 0, 2, 0, 1);
+    cut_assert_longest_match_string(1, 0, 2, qabxcd, abycdf, 0, 6, 0, 6);
+    cut_assert_longest_match_string(4, 3, 2, qabxcd, abycdf, 3, 6, 2, 6);
 }
 
 #define cut_assert_longest_match_char(expected_begin,                   \
@@ -420,14 +438,14 @@ test_get_longest_match_for_string_sequence (void)
 void
 test_get_longest_match_for_char_sequence (void)
 {
-    cut_assert_longest_match_char(0, 1, 3, "bcd", "abcdxyz", 0, 2, 0, 7);
-    cut_assert_longest_match_char(1, 2, 2, "bcd", "abcdxyz", 1, 2, 0, 6);
-    cut_assert_longest_match_char(0, 0, 0, "ab", "c", 0, 1, 0, 0);
-    cut_assert_longest_match_char(1, 0, 2, "qabxcd", "abycdf", 0, 5, 0, 5);
-    cut_assert_longest_match_char(4, 3, 2, "qabxcd", "abycdf", 3, 5, 2, 5);
+    cut_assert_longest_match_char(0, 1, 3, "bcd", "abcdxyz", 0, 3, 0, 8);
+    cut_assert_longest_match_char(1, 2, 2, "bcd", "abcdxyz", 1, 3, 0, 7);
+    cut_assert_longest_match_char(0, 0, 0, "ab", "c", 0, 2, 0, 1);
+    cut_assert_longest_match_char(1, 0, 2, "qabxcd", "abycdf", 0, 6, 0, 6);
+    cut_assert_longest_match_char(4, 3, 2, "qabxcd", "abycdf", 3, 6, 2, 6);
 
-    cut_assert_longest_match_char(0, 0, 1, "efg", "eg", 0, 2, 0, 1);
-    cut_assert_longest_match_char(2, 1, 1, "efg", "eg", 1, 2, 1, 1);
+    cut_assert_longest_match_char(0, 0, 1, "efg", "eg", 0, 3, 0, 2);
+    cut_assert_longest_match_char(2, 1, 1, "efg", "eg", 1, 3, 1, 2);
 }
 
 void
@@ -436,17 +454,17 @@ test_get_longest_match_with_junk_filter_for_string_sequence (void)
     gchar *_abcd[] = {" ", "a", "b", "c", "d", NULL};
     gchar *abcd_abcd[] = {"a", "b", "c", "d", " ", "a", "b", "c", "d", NULL};
 
-    cut_assert_longest_match_string(0, 4, 5, _abcd, abcd_abcd, 0, 4, 0, 8);
+    cut_assert_longest_match_string(0, 4, 5, _abcd, abcd_abcd, 0, 5, 0, 9);
     junk_filter_func = space_string_is_junk;
-    cut_assert_longest_match_string(1, 0, 4, _abcd, abcd_abcd, 0, 4, 0, 8);
+    cut_assert_longest_match_string(1, 0, 4, _abcd, abcd_abcd, 0, 5, 0, 9);
 }
 
 void
 test_get_longest_match_with_junk_filter_for_char_sequence (void)
 {
-    cut_assert_longest_match_char(0, 4, 5, " abcd", "abcd abcd", 0, 4, 0, 8);
+    cut_assert_longest_match_char(0, 4, 5, " abcd", "abcd abcd", 0, 5, 0, 9);
     junk_filter_func = space_char_is_junk;
-    cut_assert_longest_match_char(1, 0, 4, " abcd", "abcd abcd", 0, 4, 0, 8);
+    cut_assert_longest_match_char(1, 0, 4, " abcd", "abcd abcd", 0, 5, 0, 9);
 }
 
 static GList *
@@ -716,8 +734,8 @@ inspect_operation_func (GString *string, gconstpointer data, gpointer user_data)
     const CutSequenceMatchOperation *operation = data;
 
     g_string_append_printf(string,
-                           "<type: %s, from_begin: %d, from_end: %d, "
-                           "to_begin: %d, to_end: %d>",
+                           "<type: %s, from_begin: %u, from_end: %u, "
+                           "to_begin: %u, to_end: %u>",
                            operation_type_to_string(operation->type),
                            operation->from_begin,
                            operation->from_end,
@@ -1045,6 +1063,44 @@ test_get_ratio_for_char_sequence (void)
     cut_assert_ratio_char(0.80, "efg", "eg");
 }
 
+void
+test_set_context_size (void)
+{
+    GList *grouped_operation = NULL;
+    gchar *alnum[] = {
+        "1", "2", "3", "4", "5", "6", "7", "8", "9",
+        "a", "b", "c", "d", "e", "f", "g", "h", "i", "j", "k",
+        NULL};
+    gchar *alnum_garbage[] = {
+        "1", "i", "3", "4", "5", "6", "7", "8", "9",
+        "a", "b", "cX", "d", "h", "iX", "j", "k",
+        NULL};
+
+    grouped_operation = append_operation(NULL, EQUAL, 0, 1, 0, 1);
+    grouped_operation = append_operation(grouped_operation, REPLACE, 1, 2, 1, 2);
+    grouped_operation = append_operation(grouped_operation, EQUAL, 2, 11, 2, 11);
+    grouped_operation = append_operation(grouped_operation,
+                                         REPLACE, 11, 12, 11, 12);
+    grouped_operation = append_operation(grouped_operation,
+                                         EQUAL, 12, 13, 12, 13);
+    grouped_operation = append_operation(grouped_operation,
+                                         DELETE, 13, 16, 13, 13);
+    grouped_operation = append_operation(grouped_operation,
+                                         EQUAL, 16, 17, 13, 14);
+    grouped_operation = append_operation(grouped_operation,
+                                         REPLACE, 17, 18, 14, 15);
+    grouped_operation = append_operation(grouped_operation,
+                                         EQUAL, 18, 20, 15, 17);
+    expected_grouped_operations = g_list_append(expected_grouped_operations,
+                                                grouped_operation);
+
+    matcher = string_matcher_new(alnum, alnum_garbage);
+    cut_sequence_matcher_set_context_size(matcher, 5);
+    cut_assert_grouped_operations(expected_grouped_operations,
+                                  matcher,
+                                  inspect_string_matcher(alnum, alnum_garbage));
+}
+
 /*
 vi:ts=4:nowrap:ai:expandtab:sw=4
 */
