@@ -46,6 +46,7 @@ void test_inspect_memory_with_printable (void);
 void test_inspect_memory_huge_data (void);
 void test_compare_string_array (void);
 void test_inspect_string_array (void);
+void test_inspect_string (void);
 void test_strv_concat (void);
 void test_remove_path_recursive (void);
 void test_fold (void);
@@ -176,6 +177,19 @@ test_inspect_string_array (void)
                                       cut_utils_inspect_string_array(strings));
 }
 
+void
+test_inspect_string (void)
+{
+    cut_assert_equal_string_with_free("(null)",
+                                      cut_utils_inspect_string(NULL));
+    cut_assert_equal_string_with_free("\"a\"",
+                                      cut_utils_inspect_string("a"));
+    cut_assert_equal_string_with_free("\"a\\\"b\"",
+                                      cut_utils_inspect_string("a\"b"));
+    cut_assert_equal_string_with_free("\"a\\\\b\"",
+                                      cut_utils_inspect_string("a\\b"));
+}
+
 void
 test_strv_concat (void)
 {
@@ -713,10 +727,10 @@ void
 test_compare_string (void)
 {
     cut_assert_equal_int(0, cut_utils_compare_string(NULL, NULL));
-    cut_assert_equal_int(-1, cut_utils_compare_string(NULL, "a"));
-    cut_assert_equal_int(1, cut_utils_compare_string("a", NULL));
-    cut_assert_equal_int(-1, cut_utils_compare_string("a", "b"));
-    cut_assert_equal_int(1, cut_utils_compare_string("b", "a"));
+    cut_assert_operator_int(-1, >=, cut_utils_compare_string(NULL, "a"));
+    cut_assert_operator_int(1, <=, cut_utils_compare_string("a", NULL));
+    cut_assert_operator_int(-1, >=, cut_utils_compare_string("a", "b"));
+    cut_assert_operator_int(1, <=, cut_utils_compare_string("b", "a"));
 }
 
 void
